============
pyatlonajuno
============


.. image:: https://img.shields.io/pypi/v/pyatlonajuno.svg
        :target: https://pypi.python.org/pypi/pyatlonajuno

.. image:: https://img.shields.io/travis/hughsaunders/pyatlonajuno.svg
        :target: https://travis-ci.org/hughsaunders/pyatlonajuno

.. image:: https://readthedocs.org/projects/pyatlonajuno/badge/?version=latest
        :target: https://pyatlonajuno.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/hughsaunders/pyatlonajuno/shield.svg
     :target: https://pyup.io/repos/github/hughsaunders/pyatlonajuno/
     :alt: Updates



Python Library for controlling the Atlona Juno 451 HDMI Switch


* Free software: MIT license
* Documentation: https://pyatlonajuno.readthedocs.io.


Features
--------

* Connects via HTTP
* Switch on/off
* Get current input
* Set current input
